==> bw-xml-synchws-4.0.6-sources.jar: org/oasis_open/docs/ws_calendar/ns/soap/ErrorCodeType.java <==

package org.oasis_open.docs.ws_calendar.ns.soap;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlSeeAlso;
import javax.xml.bind.annotation.XmlType;
import org.bedework.synch.wsmessages.AlreadySubscribedType;
import org.bedework.synch.wsmessages.InvalidTokenType;
import org.bedework.synch.wsmessages.ServiceStoppedType;
import org.bedework.synch.wsmessages.UnknownSubscriptionType;
import org.bedework.synch.wsmessages.UnreachableTargetType;


/**
 * <p>Java class for ErrorCodeType complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="ErrorCodeType">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "ErrorCodeType")
@XmlSeeAlso({
    UnreachableTargetType.class,
    UnknownSubscriptionType.class,
    InvalidTokenType.class,
    AlreadySubscribedType.class,
    ServiceStoppedType.class,
    InvalidCalendarCollectionLocationType.class,
    InvalidCalendarDataType.class,
    BeforeMinDateTimeType.class,
    TooManyAttendeesPerInstanceType.class,
    TargetNotEntityType.class,
    TooManyInstancesType.class,
    TargetDoesNotExistType.class,
    PartialSuccessType.class,
    InvalidFilterType.class,
    MismatchedChangeTokenType.class,
    MissingChangeTokenType.class,
    AfterMaxDateTimeType.class,
    TargetExistsType.class,
    InvalidCalendarObjectResourceType.class,
    UnsupportedCalendarComponentType.class,
    ForbiddenType.class,
    UidConflictType.class,
    NotCalendarDataType.class,
    ExceedsMaxResourceSizeType.class
})
public class ErrorCodeType {


}

==> bw-xml-synchws-5.0.0-sources.jar: org/oasis_open/docs/ws_calendar/ns/soap/ErrorCodeType.java <==

package org.oasis_open.docs.ws_calendar.ns.soap;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlSeeAlso;
import javax.xml.bind.annotation.XmlType;
import org.bedework.synch.wsmessages.AlreadySubscribedType;
import org.bedework.synch.wsmessages.InvalidTokenType;
import org.bedework.synch.wsmessages.ServiceStoppedType;
import org.bedework.synch.wsmessages.UnknownSubscriptionType;
import org.bedework.synch.wsmessages.UnreachableTargetType;


/**
 * <p>Java class for ErrorCodeType complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="ErrorCodeType"&gt;
 *   &lt;complexContent&gt;
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType"&gt;
 *     &lt;/restriction&gt;
 *   &lt;/complexContent&gt;
 * &lt;/complexType&gt;
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "ErrorCodeType")
@XmlSeeAlso({
    AlreadySubscribedType.class,
    InvalidTokenType.class,
    UnknownSubscriptionType.class,
    UnreachableTargetType.class,
    ServiceStoppedType.class,
    ForbiddenType.class,
    TargetExistsType.class,
    TargetDoesNotExistType.class,
    TargetNotEntityType.class,
    NotCalendarDataType.class,
    InvalidCalendarDataType.class,
    InvalidCalendarObjectResourceType.class,
    UnsupportedCalendarComponentType.class,
    InvalidCalendarCollectionLocationType.class,
    ExceedsMaxResourceSizeType.class,
    BeforeMinDateTimeType.class,
    AfterMaxDateTimeType.class,
    TooManyInstancesType.class,
    TooManyAttendeesPerInstanceType.class,
    PartialSuccessType.class,
    MissingChangeTokenType.class,
    MismatchedChangeTokenType.class,
    InvalidFilterType.class,
    UidConflictType.class
})
public class ErrorCodeType {


}
